@@ -13,6 +13,10 @@
 /* This cell renderer has been modified heavily to work with the
  * TrgTorrentModel instead of libtransmission. */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
 #include <glib/gi18n.h>
@@ -322,16 +326,16 @@ static void getStatusString(GString * gstr, TorrentCellRenderer * r)
         if (priv->fileCount > 0) {
             g_string_append_printf(gstr,
                                    ngettext
-                                   ("Downloading from %1$lli of %2$lli connected peer",
-                                    "Downloading from %1$lli of %2$lli connected peers",
+                                   ("Downloading from %1$"G_GUINT64_FORMAT" of %2$"G_GUINT64_FORMAT" connected peer",
+                                    "Downloading from %1$"G_GUINT64_FORMAT" of %2$"G_GUINT64_FORMAT" connected peers",
                                     priv->webSeedsToUs + priv->peersToUs),
                                    priv->webSeedsToUs + priv->peersToUs,
                                    priv->webSeedsToUs + priv->connected);
         } else {
             g_string_append_printf(gstr,
                                    ngettext
-                                   ("Downloading metadata from %1$lli peer (%2$s done)",
-                                    "Downloading metadata from %1$lli peers (%2$s done)",
+                                   ("Downloading metadata from %1$"G_GUINT64_FORMAT" peer (%2$s done)",
+                                    "Downloading metadata from %1$"G_GUINT64_FORMAT" peers (%2$s done)",
                                     priv->connected + priv->webSeedsToUs),
                                    priv->connected + priv->webSeedsToUs,
                                    tr_strlpercent(buf,
@@ -341,8 +345,8 @@ static void getStatusString(GString * gstr, TorrentCellRenderer * r)
     } else if (priv->flags & TORRENT_FLAG_SEEDING) {
         g_string_append_printf(gstr,
                                ngettext
-                               ("Seeding to %1$lli of %2$lli connected peer",
-                                "Seeding to %1$lli of %2$lli connected peers",
+                               ("Seeding to %1$"G_GUINT64_FORMAT" of %2$"G_GUINT64_FORMAT" connected peer",
+                                "Seeding to %1$"G_GUINT64_FORMAT" of %2$"G_GUINT64_FORMAT" connected peers",
                                 priv->connected), priv->peersFromUs,
                                priv->connected);
     }
